{% extends "photologue/root.html" %}
{% load i18n %}

{% block title %}{% blocktrans with show_day=day|date:"d F Y" %}Galleries for {{ show_day }}{% endblocktrans %}{% endblock %}

{% block content %}

    <div class="row col-lg-12">
        <h1 class="page-header">{% blocktrans with show_day=day|date:"d F Y" %}Galleries for {{ show_day }}{% endblocktrans %}</h1>
    </div>

    <div class="row col-lg-12">
        {% if object_list %}
            {% for gallery in object_list %}
                {% include "photologue/includes/gallery_sample.html" %}
            {% endfor %}
        {% else %}
            <p>{% trans "No galleries were found." %}</p>
        {% endif %}
    </div>
    
    <div><a href="{% url 'photologue:gallery-archive-month' day.year day|date:"m"|lower %}" class="btn btn-default">{% trans "View all galleries for month" %}</a></div>

{% endblock %}
