{% extends "photologue/root.html" %}
{% load i18n %}

{% block title %}{% blocktrans with show_day=day|date:"d F Y" %}Photos for {{ show_day }}{% endblocktrans %}{% endblock %}

{% block content %}

    <div class="row col-lg-12">
        <h1 class="page-header">{% blocktrans with show_day=day|date:"d F Y" %}Photos for {{ show_day }}{% endblocktrans %}</h1>
    </div>

	{% if object_list %}
		<div class="row col-lg-12">
		    {% for photo in object_list %}
		        <a href="{{ photo.get_absolute_url }}">
		             <img src="{{ photo.get_thumbnail_url }}" class="thumbnail" alt="{{ photo.title }}">
		        </a>
		    {% endfor %}
		</div>
	{% else %}
		<p>{% trans "No photos were found" %}.</p>
	{% endif %}

    <div><a href="{% url 'photologue:photo-archive-month' day.year day|date:"m"|lower %}" class="btn btn-default">{% trans "View all photos for month" %}</a></div>

{% endblock %}
