{% extends "photologue/root.html" %}
{% load i18n %}

{% block title %}{% blocktrans with show_year=year|date:"Y" %}Galleries for {{ show_year }}{% endblocktrans %}{% endblock %}

{% block content %}

    <div class="row col-lg-12">
        <h1 class="page-header">{% blocktrans with show_year=year|date:"Y" %}Galleries for {{ show_year }}{% endblocktrans %}</h1>
    </div>

	<div class="row">

		<aside class="col-md-2">

			<h4>{% trans "Filter by month" %}</h4>
			<ul>
				{% for date in date_list %}
					<li><a href="{% url 'photologue:gallery-archive-month' date.year date|date:"m"|lower %}">{{ date|date:"F" }}</a></li>
				{% endfor %}
			</ul>

		</aside>

		<main class="col-md-10">

			{% if object_list %}
				{% for gallery in object_list %}
			        {% include "photologue/includes/gallery_sample.html" %}
			    {% endfor %}
			{% else %}
			    <p>{% trans "No galleries were found." %}</p>
			{% endif %}

		    <div><a href="{% url 'photologue:pl-gallery-archive' %}" class="btn btn-default">{% trans "View all galleries" %}</a></div>

		</main>

	</div>

{% endblock %}
